.. currentmodule:: sardana.macroserver.macros.test.test_wm
.. _test_wm:

:mod:`~sardana.macroserver.macros.test.test_wm`
===============================================

.. automodule:: sardana.macroserver.macros.test.test_wm

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`WBase`
    * :class:`WmTest`



WBase
-----

.. inheritance-diagram:: WBase
    :parts: 1

.. autoclass:: WBase
    :members:
    :undoc-members:

WmTest
------

.. inheritance-diagram:: WmTest
    :parts: 1

.. autoclass:: WmTest
    :members:
    :undoc-members:
